==> zio-aws-kafka_2.13-5.17.126.2-sources.jar: zio/aws/kafka/model/ListClustersResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListClustersResponse(
    clusterInfoList: Option[Iterable[zio.aws.kafka.model.ClusterInfo]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListClustersResponse = {
    import ListClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListClustersResponse
      .builder()
      .optionallyWith(
        clusterInfoList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.clusterInfoList)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListClustersResponse.ReadOnly =
    zio.aws.kafka.model.ListClustersResponse.wrap(buildAwsValue())
}
object ListClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListClustersResponse =
      zio.aws.kafka.model.ListClustersResponse(
        clusterInfoList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def clusterInfoList: Option[List[zio.aws.kafka.model.ClusterInfo.ReadOnly]]
    def nextToken: Option[__string]
    def getClusterInfoList
        : ZIO[Any, AwsError, List[zio.aws.kafka.model.ClusterInfo.ReadOnly]] =
      AwsError.unwrapOptionField("clusterInfoList", clusterInfoList)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ) extends zio.aws.kafka.model.ListClustersResponse.ReadOnly {
    override val clusterInfoList
        : Option[List[zio.aws.kafka.model.ClusterInfo.ReadOnly]] = scala
      .Option(impl.clusterInfoList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.ClusterInfo.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ): zio.aws.kafka.model.ListClustersResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.130.5-sources.jar: zio/aws/kafka/model/ListClustersResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListClustersResponse(
    clusterInfoList: Option[Iterable[zio.aws.kafka.model.ClusterInfo]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListClustersResponse = {
    import ListClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListClustersResponse
      .builder()
      .optionallyWith(
        clusterInfoList.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.clusterInfoList)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListClustersResponse.ReadOnly =
    zio.aws.kafka.model.ListClustersResponse.wrap(buildAwsValue())
}
object ListClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListClustersResponse =
      zio.aws.kafka.model.ListClustersResponse(
        clusterInfoList.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def clusterInfoList: Option[List[zio.aws.kafka.model.ClusterInfo.ReadOnly]]
    def nextToken: Option[__string]
    def getClusterInfoList
        : ZIO[Any, AwsError, List[zio.aws.kafka.model.ClusterInfo.ReadOnly]] =
      AwsError.unwrapOptionField("clusterInfoList", clusterInfoList)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ) extends zio.aws.kafka.model.ListClustersResponse.ReadOnly {
    override val clusterInfoList
        : Option[List[zio.aws.kafka.model.ClusterInfo.ReadOnly]] = scala
      .Option(impl.clusterInfoList())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.ClusterInfo.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListClustersResponse
  ): zio.aws.kafka.model.ListClustersResponse.ReadOnly = new Wrapper(impl)
}
